@@ -17,7 +17,7 @@ typedef struct {
 static PyTypeObject EMatrixType;
 
 #define EVSPACE_MODULE
-#include "evspacemodule.h"
+#include <evspacemodule.h>
 
 #define PI 3.14159265358979323846
 
